aboutsummaryrefslogtreecommitdiff
path: root/gdb/pyr-xdep.c
diff options
context:
space:
mode:
Diffstat (limited to 'gdb/pyr-xdep.c')
-rw-r--r--gdb/pyr-xdep.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gdb/pyr-xdep.c b/gdb/pyr-xdep.c
index bedbc61..e205b50 100644
--- a/gdb/pyr-xdep.c
+++ b/gdb/pyr-xdep.c
@@ -171,7 +171,7 @@ extern unsigned int last_frame_offset;
#ifdef PYRAMID_CORE
/* Can't make definitions here static, since core.c needs them
to do bounds checking on the core-file areas. O well. */
/* have two stacks: one for data, one for register windows. */
@@ -192,7 +192,7 @@ extern int reg_stack_offset;
/* Work with core dump and executable files, for GDB.
- This code would be in core.c if it weren't machine-dependent. */
+ This code would be in corefile.c if it weren't machine-dependent. */
void
core_file_command (filename, from_tty)
@@ -171,7 +171,7 @@ extern unsigned int last_frame_offset;
#ifdef PYRAMID_CORE
-/* Can't make definitions here static, since core.c needs them
+/* Can't make definitions here static, since corefile.c needs them
to do bounds checking on the core-file areas. O well. */
/* have two stacks: one for data, one for register windows. */